@@ -179,6 +179,7 @@ static void advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin *);
 static void advanced_backlight_plugin_load_settings (AdvancedBacklightPlugin * vsp);
 static void advanced_backlight_plugin_save_settings (AdvancedBacklightPlugin * vsp);
 static void advanced_backlight_plugin_fill_theme_list (AdvancedBacklightPlugin * vsp, GtkWidget * combobox);
+static int get_light_sensor(AdvancedBacklightPlugin * vsp);
 static gboolean is_n810 ();
 
 #ifdef XRANDR
@@ -627,14 +628,15 @@ advanced_backlight_plugin_update_rotate_button_orientation (AdvancedBacklightPlu
     return;
 
   rotation = advanced_backlight_plugin_get_rotation (vsp);
+  g_debug ("current rotation is %d\n", rotation);
 
   rot_pfd = pango_font_description_copy (priv->menu->style->font_desc);
   pango_font_description_set_size (rot_pfd, 30 * PANGO_SCALE);
 
   for (i = 0; i < 4; i++)
     {
-      /* gtk_widget_set_sensitive (priv->rotation_button[i], i != rotation); */
-      pango_font_description_set_gravity (rot_pfd, (4 - rotation + (i + 2)) % 4);
+      gtk_widget_set_sensitive (priv->rotation_button[i], i != rotation);
+      pango_font_description_set_gravity (rot_pfd, (4 - rotation + i) % 4);
       gtk_widget_modify_font (GTK_WIDGET (gtk_bin_get_child (GTK_BIN (priv->rotation_button[i]))), rot_pfd);
     }
   pango_font_description_free (rot_pfd);
@@ -654,7 +656,7 @@ rotation_button_clicked (GtkButton * button, AdvancedBacklightPlugin * vsp)
     {
       if (button == GTK_BUTTON (priv->rotation_button[i]))
         {
-          advanced_backlight_plugin_set_rotation (vsp, (i + 2) % 4);
+          advanced_backlight_plugin_set_rotation (vsp, i);
           g_debug ("rotate %d\n", i);
         }
     }
@@ -889,40 +891,31 @@ show_menu (GtkButton * widget, AdvancedBacklightPlugin * vsp)
 
 
 #ifdef XRANDR
-/* Helper functions */
-static gint
-advanced_backlight_plugin_xrr_supported (AdvancedBacklightPlugin * vsp)
+static void
+advanced_backlight_plugin_check_init_rotation (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  Display *dpy;
   int xrr_event_base, xrr_error_base;
   int xrr_major, xrr_minor;
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
-  if (XRRQueryExtension (priv->dpy, &xrr_event_base, &xrr_error_base) == False
-      || XRRQueryVersion (priv->dpy, &xrr_major, &xrr_minor) == 0 || xrr_major != 1 || xrr_minor < 1)
-    return FALSE;
-
-  return TRUE;
-}
-
-
-static void
-advanced_backlight_plugin_check_init_rotation (AdvancedBacklightPlugin * vsp)
-{
-  AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
-
-  g_debug ("%s\n", __PRETTY_FUNCTION__);
-
-  priv->dpy = XOpenDisplay (NULL);
-  if (priv->dpy == NULL)
+  dpy = XOpenDisplay (NULL);
+  if (dpy == NULL)
     {
       fprintf (stderr, "Couldn't open display\n");
       priv->has_rotation = FALSE;
       return;
     }
-  priv->screen = DefaultScreen (priv->dpy);
-  priv->has_rotation = advanced_backlight_plugin_xrr_supported (vsp);
+
+  if (XRRQueryExtension (dpy, &xrr_event_base, &xrr_error_base) == False
+      || XRRQueryVersion (dpy, &xrr_major, &xrr_minor) == 0 || xrr_major != 1 || xrr_minor < 1)
+    priv->has_rotation = FALSE;
+  else
+    priv->has_rotation = TRUE;
+
+  XCloseDisplay (dpy);
 }
 
 
@@ -933,14 +926,19 @@ advanced_backlight_plugin_get_rotation (AdvancedBacklightPlugin * vsp)
   gint rotation;
   XRRScreenConfiguration *rr_screen;
   Rotation current_rotation;
-
   g_debug ("%s\n", __PRETTY_FUNCTION__);
+  Display *dpy;
+  gint screen;
 
-  if (priv->dpy == NULL)
+  if (!priv->has_rotation)
     return 0;
 
-  rr_screen = XRRGetScreenInfo (priv->dpy, RootWindow (priv->dpy, priv->screen));
-  XRRRotations (priv->dpy, priv->screen, &current_rotation);
+  dpy = XOpenDisplay (NULL);
+  screen = DefaultScreen (dpy);
+
+  rr_screen = XRRGetScreenInfo (dpy, RootWindow (dpy, screen));
+  XRRRotations (dpy, screen, &current_rotation);
+
   XRRFreeScreenConfigInfo (rr_screen);
 
   switch (current_rotation)
@@ -963,6 +961,8 @@ advanced_backlight_plugin_get_rotation (AdvancedBacklightPlugin * vsp)
       break;
     }
 
+  XCloseDisplay (dpy);
+
   return rotation;
 }
 
@@ -976,13 +976,18 @@ advanced_backlight_plugin_set_rotation (AdvancedBacklightPlugin * vsp, gint rota
   Rotation current_rotation;
   gint size;
   int i;
+  Display *dpy;
+  gint screen;
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
-  if (priv->dpy == NULL)
+  if (!priv->has_rotation)
     return;
 
-  scr_config = XRRGetScreenInfo (priv->dpy, RootWindow (priv->dpy, priv->screen));
+  dpy = XOpenDisplay (NULL);
+  screen = DefaultScreen (dpy);
+
+  scr_config = XRRGetScreenInfo (dpy, RootWindow (dpy, screen));
   size = XRRConfigCurrentConfiguration (scr_config, &current_rotation);
 
   switch (rotation)
@@ -1009,11 +1014,13 @@ advanced_backlight_plugin_set_rotation (AdvancedBacklightPlugin * vsp, gint rota
   for (i = 0; i < 4; i++)
     {
       KeySym keysym = XStringToKeysym (keyname[(rotation + i) % 4]);
-      XChangeKeyboardMapping (priv->dpy, keycode[i], 1, &keysym, 1);
+      XChangeKeyboardMapping (dpy, keycode[i], 1, &keysym, 1);
     }
 
-  XRRSetScreenConfig (priv->dpy, scr_config, RootWindow (priv->dpy, priv->screen), size, sc_rotation, CurrentTime);
+  XRRSetScreenConfig (dpy, scr_config, RootWindow (dpy, screen), size, sc_rotation, CurrentTime);
   XRRFreeScreenConfigInfo (scr_config);
+  XCloseDisplay (dpy);
+
 }
 
 
@@ -1405,6 +1412,21 @@ advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin * vsp)
 
 }
 
+static int get_light_sensor(AdvancedBacklightPlugin * vsp) {
+  /*AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);*/
+  int value = -1;
+  FILE * fp;
+
+  fp = fopen("/sys/devices/platform/i2c_omap.2/i2c-0/0-0029/lux","r");
+
+  if (fp) {
+    fscanf(fp,"%d",&value);
+    fclose(fp);
+  }
+
+  return(value);
+}
+
 #ifdef TEST_PLUGIN
 /* used for testing the plugin and debugging */
 int
@@ -1434,7 +1456,7 @@ main (int argc, char *argv[])
   main_layout = gtk_fixed_new ();
   gtk_container_add (GTK_CONTAINER (window), main_layout);
   vsp = advanced_backlight_plugin_new ();
-  gtk_fixed_put (GTK_FIXED (main_layout), vsp, 550, 0);
+  gtk_fixed_put (GTK_FIXED (main_layout), vsp, 300, 0);
   gtk_widget_set_size_request (GTK_WIDGET (vsp), 45, 45);
   gtk_widget_show_all (GTK_WIDGET (window));
   gtk_main ();
